@@ -429,7 +429,7 @@ class PhContextFacade(object):
                 cmd_arr.append(it)
 
         phlogger.info(cmd_arr)
-        return subprocess.check_output(cmd_arr, shell=True, stderr=subprocess.STDOUT)
+        return subprocess.call(cmd_arr)
 
     def command_logs_exec(self):
         pass
